==> rec10%200.9.0.tar.bz2: rec10 0.9.0/rec10/tv2ts.py <==
#!/usr/bin/python
# coding: UTF-8
#import sys # モジュール属性 argv を取得するため
import commands
import os
import shutil
import time
import sys

import configreader
import status
import recdblist
mypath = str(os.path.dirname(os.path.abspath(__file__))) + "/"
def tv2tsmix(pout, ch, time):
    tv2b25ts(pout + ".b25", ch, time)
    b252tsmix(pout + ".b25", pout)
    #if os.access(pout, os.F_OK):
    #    try:
    #        os.remove(pout + ".b25")
    #    except:
    #        ""
def tv2ts(pout, ch, csch, time):
    ext = os.path.splitext(pout)[1]#ext=".なんたら"
    tempt = os.path.split(pout)
    path = tempt[0]
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(1)
    else:
        status.changeTERecording(1)
    try:
        tv2b25ts(pout + ".b25", ch, time)
    except Exception, inst:
        print "error occures in tv2ts.py tv2ts"
        print type(inst)
        print inst
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(-1)
    else:
        status.changeTERecording(-1)
    b252tsmix(pout + ".b25", pout + ".tsmix")
    tch="0"
    if csch!=u"0":
        tch=csch
    elif ch==u"101":
        tch="101"
    elif ch==u"102":
        tch="102"
    #else:
    #    tch=ch
    tsmix2ts(pout + ".tsmix", pout, tch)
    if os.access(pout, os.F_OK):
        try:
            #os.remove(path + "/" + t + ext)
            ""
        except:
            ""
def b252ts(pout, ch, csch):
    ext = os.path.splitext(pout)[1]#ext=".なんたら"
    tempt = os.path.split(pout)
    path = tempt[0]
    b252tsmix(pout + ".b25", pout + ".tsmix")
    tch=u"0"
    if csch!=u"0":
        tch=csch
    elif ch==u"101":
        tch=u"101"
    elif ch==u"102":
        tch=u"102"
    #else:
    #    tch=ch
    tsmix2ts(pout + ".tsmix", pout, tch)
    if os.access(pout, os.F_OK):
        try:
            #os.remove(path + "/" + t + ext)
            ""
        except:
            ""
def tv2b25ts(pout, ch, time):
    exe = configreader.getpath('recpt1')
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(1)
    else:
        status.changeTERecording(1)
    try:
        doexe = exe + ' ' + ch + ' ' + time + ' \'' + pout + '\''
        recdblist.printutf8(doexe)
        txt=u"####recpt1-log####\n"
        txt = txt + unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
        logo=pout.replace(".ts.b25",".log")
        f=open(logo,'w')
        f.write(txt.encode('utf-8'))
        f.close()
    except Exception, inst:
        print "error occures in tv2ts.py tv2b25ts"
        print type(inst)
        print inst
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(-1)
    else:
        status.changeTERecording(-1)
def tv2b25ts_b25(pout, ch, time):
    exe = configreader.getpath('recpt1')
    doexe = exe + ' --b25 ' + ch + ' ' + time + ' \'' + pout + '\''
    os.system(doexe)
def b252tsmix(pin, pout):
    if not (os.path.exists(pout) and os.path.getsize(pin)==os.path.getsize(pout)):
        exe=""
        if configreader.getpath('b25_remote')=="1":
            try:
                exe = configreader.getpath('b25_env')+" && "
            except:
                recdblist.printutf8(u"b25_remoteがオンになっていますが、b25_envが設定されていないかコメントアウトされています。")
        exe = exe + "nice -n 17 " + configreader.getpath('b25')
        doexe = exe + u' \"' + pin + u'\" \"' + pout + u'\"'
        recdblist.printutf8(doexe)
        sys.stdout.flush()
        logo=pin.replace(".ts.b25",".log")
        txt = unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
        s=len(txt)
        stxt=""
        if s>1000:
            s=s-1000
            stxt=txt[s:]
        else:
            stxt=txt
        s=stxt.find("\n")
        if s>0:
            s=s+len("\n")
            stxt=stxt[s:]
        txt = "\n####b25-log####\n"+stxt
        f=open(logo,'a')
        f.write(txt.encode('utf-8'))
        f.close()
def tsmix2ts(pin, pout, csch):#csch=0ならcsの処理をしない
    """if csch==0:
        shutil.move(pin,pout)
    else:"""
    doexe = configreader.getpath("tssplitter") + " \""+ pin + "\" \""+ pout + "\" " + str(csch)
    doexe = "nice -n 18 " + doexe
    logo=pin.replace(".ts.tsmix",".log")
    os.environ['LANG']="ja_JP.UTF-8"
    txt = unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
    stxt=txt
    txt = "\n####tssplit-log####\nCommand:"+doexe+"\nlog:\n"+stxt
    f=open(logo,'a')
    f.write(txt.encode('utf-8'))
    f.close()
    time.sleep(1)
    if os.access(pout, os.F_OK):
        os.remove(pin)

==> rec10%200.9.1.tar.bz2: rec10 0.9.1/rec10/tv2ts.py <==
#!/usr/bin/python
# coding: UTF-8
#import sys # モジュール属性 argv を取得するため
import commands
import os
import os.path
import time

import configreader
import status
import recdblist
mypath = str(os.path.dirname(os.path.abspath(__file__))) + "/"
def tv2tsmix(pout, ch, time):
    tv2b25ts(pout + ".b25", ch, time)
    b252tsmix(pout + ".b25", pout)
    #if os.access(pout, os.F_OK):
    #    try:
    #        os.remove(pout + ".b25")
    #    except:
    #        ""
def tv2ts(pout, ch, csch, time):
    ext = os.path.splitext(pout)[1]#ext=".なんたら"
    tempt = os.path.split(pout)
    path = tempt[0]
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(1)
    else:
        status.changeTERecording(1)
    try:
        tv2b25ts(pout + ".b25", ch, time)
    except Exception, inst:
        print "error occures in tv2ts.py tv2ts"
        print type(inst)
        print inst
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(-1)
    else:
        status.changeTERecording(-1)
    b252tsmix(pout + ".b25", pout + ".tsmix")
    tch="0"
    if csch!=u"0":
        tch=csch
    elif ch==u"101":
        tch="101"
    elif ch==u"102":
        tch="102"
    #else:
    #    tch=ch
    tsmix2ts(pout + ".tsmix", pout, tch)
    if os.access(pout, os.F_OK):
        try:
            #os.remove(path + "/" + t + ext)
            ""
        except:
            ""
def b252ts(pout, ch, csch):
    ext = os.path.splitext(pout)[1]#ext=".なんたら"
    tempt = os.path.split(pout)
    path = tempt[0]
    b252tsmix(pout + ".b25", pout + ".tsmix")
    tch=u"0"
    if csch!=u"0":
        tch=csch
    elif ch==u"101":
        tch=u"101"
    elif ch==u"102":
        tch=u"102"
    #else:
    #    tch=ch
    tsmix2ts(pout + ".tsmix", pout, tch)
    if os.access(pout, os.F_OK):
        try:
            #os.remove(path + "/" + t + ext)
            ""
        except:
            ""
def tv2b25ts(pout, ch, time):
    exe = configreader.getpath('recpt1')
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(1)
    else:
        status.changeTERecording(1)
    try:
        doexe = exe + ' ' + ch + ' ' + time + ' \'' + pout + '\''
        recdblist.printutf8(doexe)
        recdblist.addlog(pout, unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8'), u"recpt1-log")
    except Exception, inst:
        print "error occures in tv2ts.py tv2b25ts"
        print type(inst)
        print inst
    if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
        status.changeBSCSRecording(-1)
    else:
        status.changeTERecording(-1)
def tv2b25ts_b25(pout, ch, time):
    exe = configreader.getpath('recpt1')
    doexe = exe + ' --b25 ' + ch + ' ' + time + ' \'' + pout + '\''
    os.system(doexe)
def b252tsmix(pin, pout):
    if not (os.path.exists(pout) and os.path.getsize(pin)>os.path.getsize(pout)*0.95 and os.path.getsize(pin)<os.path.getsize(pout)*1.05):
        exe=""
        if configreader.getpath('b25_remote')=="1":
            try:
                exe = configreader.getpath('b25_env')+" && "
            except:
                recdblist.printutf8(u"b25_remoteがオンになっていますが、b25_envが設定されていないかコメントアウトされています。")
        exe = exe + "nice -n 17 " + configreader.getpath('b25')
        doexe = exe + u' \"' + pin + u'\" \"' + pout + u'\"'
        recdblist.printutf8(doexe)
        txt = unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
        recdblist.addlog(pin, txt, u"b25-log")
def tsmix2ts(pin, pout, csch):#csch=0ならcsの処理をしない
    """if csch==0:
        shutil.move(pin,pout)
    else:"""
    doexe = configreader.getpath("tssplitter") + " \""+ pin + "\" \""+ pout + "\" " + str(csch)
    doexe = "nice -n 18 " + doexe
    os.environ['LANG']="ja_JP.UTF-8"
    txt = unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8')
    txt = doexe+"\n\n"+txt
    recdblist.addlog(pin, txt, "tssplit-log")
    time.sleep(1)
    if os.access(pout, os.F_OK) and os.path.getsize(pout)>10*1000*1000:
        os.remove(pin)
